<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>MircastShowWidget</name>
    <message>
        <location filename="../src/widgets/mircastshowwidget.cpp" line="57"/>
        <source>Exit Miracast</source>
        <translation>Miracast&apos;tan çık</translation>
    </message>
    <message>
        <location filename="../src/widgets/mircastshowwidget.cpp" line="74"/>
        <source>Projecting... 
Please do not exit the Movie app during the process.</source>
        <translation>Projelendiriliyor...
Lütfen işlem sırasında Film uygulamasından çıkmayın.</translation>
    </message>
    <message>
        <location filename="../src/widgets/mircastshowwidget.cpp" line="102"/>
        <source>Display device</source>
        <translation>Görüntü cihazı</translation>
    </message>
</context>
<context>
    <name>MircastWidget</name>
    <message>
        <location filename="../src/widgets/mircastwidget.cpp" line="71"/>
        <source>Project to</source>
        <translation>Proje</translation>
    </message>
    <message>
        <location filename="../src/widgets/mircastwidget.cpp" line="369"/>
        <source>Searching for devices...</source>
        <translation>Cihazlar aranıyor...</translation>
    </message>
    <message>
        <location filename="../src/widgets/mircastwidget.cpp" line="378"/>
        <source>No Miracast display devices were found. Please connect the device and your computer to the same WLAN network.</source>
        <translation>Miracast görüntüleme cihazı bulunamadı. Lütfen cihazı ve bilgisayarınızı aynı WLAN ağına bağlayın.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/backends/mpv/mpv_proxy.cpp" line="582"/>
        <source>Movie</source>
        <translation>Sinema</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="289"/>
        <source>Movie is a full-featured video player, supporting playing local and streaming media in multiple video formats.</source>
        <translation>Film, yerel ve akışlı ortamların birden fazla video biçiminde oynatılmasını destekleyen tam özellikli bir video oynatıcıdır.</translation>
    </message>
    <message>
        <location filename="../src/common/shortcut_manager.cpp" line="186"/>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <location filename="../src/common/shortcut_manager.cpp" line="189"/>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <location filename="../src/common/shortcut_manager.cpp" line="194"/>
        <source>Display shortcuts</source>
        <translation>Kısayolları görüntüle</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="10"/>
        <source>Auto add similar files to play</source>
        <translation>Oynatmak için benzer dosyaları otomatik olarak ekle</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="11"/>
        <source>Clear playlist when exit</source>
        <translation>Çıkışta oynatma listesi temizle</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="12"/>
        <source>Show thumbnails in progress bar</source>
        <translation>Devam eden küçük resimleri göster</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="13"/>
        <source>Show video preview on mouseover</source>
        <translation>Fare ile üzerine gelindiğinde ön izlemeyi görüntüle</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="14"/>
        <source>Open a new player for each file played</source>
        <translation>Oynatılan her dosya için yeni bir oynatıcı aç</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="15"/>
        <source>Pause when minimized</source>
        <translation>Küçültüldüğünde duraklat</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="16"/>
        <source>Remember playback position</source>
        <translation>Oynatma konumu hatırla</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="17"/>
        <source>Default play mode</source>
        <translation>Varsayılan oynatma kipi</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="18"/>
        <source>Path</source>
        <translation>Yol</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="19"/>
        <source>Basic</source>
        <translation>Temel</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="20"/>
        <source>Play</source>
        <translation>Oynat</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="21"/>
        <source>Screenshot</source>
        <translation>Ekran görüntüsü</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="22"/>
        <source>Shortcuts</source>
        <translation>Kısayollar</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="23"/>
        <source>File</source>
        <translation>Dosya</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="24"/>
        <source>Frame/Sound</source>
        <translation>Kare/Ses</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="25"/>
        <source>Playback</source>
        <translation>Oynatma</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="27"/>
        <source>Subtitle</source>
        <translation>Alt yazı</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="29"/>
        <source>Font Style</source>
        <translation>Yazı Tipi Biçimi</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="30"/>
        <source>Restore Defaults</source>
        <translation>Varsayılanları Geri Yükle</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="31"/>
        <source>Open file</source>
        <translation>Dosya aç</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="32"/>
        <source>Open next</source>
        <translation>Sonrakini aç</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="33"/>
        <source>Open previous</source>
        <translation>Öncekini aç</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="34"/>
        <source>Mini mode</source>
        <translation>Mini kip</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="35"/>
        <source>Mute</source>
        <translation>Sesi kapat</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="36"/>
        <source>Next frame</source>
        <translation>Sonraki kare</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="37"/>
        <source>Previous frame</source>
        <translation>Önceki kare</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="38"/>
        <source>Volume down</source>
        <translation>Sesi azalt</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="39"/>
        <source>Volume up</source>
        <translation>Sesi yükselt</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="40"/>
        <source>Speed up</source>
        <translation>Hızı arttır</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="41"/>
        <source>Speed down</source>
        <translation>Hızı azalt</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="42"/>
        <source>Fullscreen</source>
        <translation>Tam ekran</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="43"/>
        <source>Pause/Play</source>
        <translation>Duraklat/Oynat</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="44"/>
        <source>Playlist</source>
        <translation>Oynatma listesi</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="45"/>
        <source>Reset speed</source>
        <translation>Hızı sıfırla</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="46"/>
        <source>Delete from playlist</source>
        <translation>Oynatma listesini sil</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="47"/>
        <source>Film info</source>
        <translation>Film bilgileri</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="48"/>
        <source>Rewind</source>
        <translation>Geri sar</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="49"/>
        <source>Forward</source>
        <translation>İleri sar</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="50"/>
        <source>Burst shooting</source>
        <translation>Seri çekim</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="51"/>
        <source>Film screenshot</source>
        <translation>Film ekran görüntüsü</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="52"/>
        <source>0.5s backward</source>
        <translation>0.5s geri</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="53"/>
        <source>0.5s forward</source>
        <translation>0.5s ileri</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="54"/>
        <source>Font</source>
        <translation>Yazı tipi</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="55"/>
        <source>Size</source>
        <translation>Boyut</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="56"/>
        <source>Exit fullscreen/mini mode</source>
        <translation>Tam ekran/mini kipten çık</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="60"/>
        <source>Decoding</source>
        <translation>Kod çözümü</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="61"/>
        <source>Auto select (Recommended)</source>
        <translation>Otomatik seç (Önerilen)</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="62"/>
        <source>Hardware decoding</source>
        <translation>Donanım kod çözümü</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="63"/>
        <source>Software decoding</source>
        <translation>Yazılım kod çözümü</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="64"/>
        <source>Customize</source>
        <translation>Özelleştir</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="65"/>
        <source>Decode mode</source>
        <translation>Çözümleme modu</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="66"/>
        <source>Video out</source>
        <translation>Video çıkış</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="67"/>
        <source>Rendering engine</source>
        <translation>Görsel motoru</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="322"/>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Bu klasörde işlem yapma izniniz yok</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="324"/>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="340"/>
        <source>Invalid folder</source>
        <translation>Geçersiz klasör</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="360"/>
        <source>Open folder</source>
        <translation>Klasör aç</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2872"/>
        <source>The custom decoding method needs to be restarted before it can take effect,
and whether to restart it?</source>
        <translation>Özelleştirilmiş çözümlendirme yöntemi etkili olmak için yeniden başlatılmalıdır,

yeniden başlatılacak mı?</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3261"/>
        <source>Network disconnected</source>
        <translation>Ağ bağlantısı kesildi</translation>
    </message>
</context>
<context>
    <name>UrlDialog</name>
    <message>
        <location filename="../src/widgets/url_dialog.cpp" line="19"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../src/widgets/url_dialog.cpp" line="20"/>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
    <message>
        <location filename="../src/widgets/url_dialog.cpp" line="26"/>
        <source>Please enter the URL:</source>
        <translation>Lütfen URL&apos;yi gir:</translation>
    </message>
</context>
<context>
    <name>dmr::ActionFactory</name>
    <message>
        <location filename="../src/common/actions.cpp" line="53"/>
        <source>Open file</source>
        <translation>Dosya aç</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="55"/>
        <source>Open folder</source>
        <translation>Klasör aç</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="56"/>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="66"/>
        <source>Play Mode</source>
        <translation>Oynatma Kipi</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="68"/>
        <source>Order Play</source>
        <translation>Oynatma Sırası</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="69"/>
        <source>Shuffle Play</source>
        <translation>Karışık Oynat</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="70"/>
        <source>Single Play</source>
        <translation>Tek Oynat</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="71"/>
        <source>Single Loop</source>
        <translation>Parça Döngüsü</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="72"/>
        <source>List Loop</source>
        <translation>Liste Döngüsü</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="77"/>
        <source>Frame</source>
        <translation>Kare</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="79"/>
        <source>Default</source>
        <translation>Varsayılan</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="86"/>
        <source>Clockwise</source>
        <translation>Saat yönünde</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="87"/>
        <source>Counterclockwise</source>
        <translation>Saat yönünün tersine</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="89"/>
        <source>Next Frame</source>
        <translation>Sonraki Kare</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="90"/>
        <source>Previous Frame</source>
        <translation>Önceki Kare</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="99"/>
        <source>Playback Speed</source>
        <translation>Oynatım Hızı</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="101"/>
        <source>0.5x</source>
        <translation>0.5x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="102"/>
        <source>1.0x</source>
        <translation>1.0x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="103"/>
        <source>1.2x</source>
        <translation>1.2x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="104"/>
        <source>1.5x</source>
        <translation>1.5x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="105"/>
        <source>2.0x</source>
        <translation>2.0x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="129"/>
        <source>Open URL</source>
        <translation>Adres Aç</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="130"/>
        <source>Open CD/DVD</source>
        <translation>CD/DVD Aç</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="132"/>
        <source>Fullscreen</source>
        <translation>Tam ekran</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="133"/>
        <source>Mini Mode</source>
        <translation>Mini Kip</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="134"/>
        <source>Always on Top</source>
        <translation>Her Zaman Üstte</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="187"/>
        <source>Sound</source>
        <translation>Ses</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="191"/>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="194"/>
        <source>Stereo</source>
        <translation>Çift kanal</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="195"/>
        <source>Left channel</source>
        <translation>Sol kanal</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="196"/>
        <source>Right channel</source>
        <translation>Sağ kanal</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="201"/>
        <source>Track</source>
        <translation>Parça</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="214"/>
        <source>Subtitle</source>
        <translation>Alt yazı</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="216"/>
        <source>Load</source>
        <translation>Yükle</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="217"/>
        <source>Online Search</source>
        <translation>Çevrimiçi Ara</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="221"/>
        <source>Select</source>
        <translation>Seç</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="225"/>
        <source>Hide</source>
        <translation>Gizle</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="228"/>
        <source>Encodings</source>
        <translation>Kodlamalar</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="295"/>
        <source>Screenshot</source>
        <translation>Ekran görüntüsü</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="298"/>
        <source>Film Screenshot</source>
        <translation>Film Ekran Görüntüsü</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="299"/>
        <source>Burst Shooting</source>
        <translation>Seri Çekim</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="300"/>
        <source>Open screenshot folder</source>
        <translation>Ekran görüntüsü klasörünü aç</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="308"/>
        <source>Playlist</source>
        <translation>Oynatma listesi</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="309"/>
        <source>Film Info</source>
        <translation>Film Bilgileri</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="375"/>
        <source>Delete from playlist</source>
        <translation>Oynatma listesini sil</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="376"/>
        <source>Empty playlist</source>
        <translation>Boş oynatma listesi</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="377"/>
        <source>Display in file manager</source>
        <translation>Dosya yöneticisinde görüntüle</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="378"/>
        <source>Film info</source>
        <translation>Film bilgileri</translation>
    </message>
</context>
<context>
    <name>dmr::BurstScreenshotsDialog</name>
    <message>
        <location filename="../src/widgets/burst_screenshots_dialog.cpp" line="44"/>
        <source>Duration: %1</source>
        <translation>Süre: %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/burst_screenshots_dialog.cpp" line="49"/>
        <source>Resolution: %1</source>
        <translation>Çözünürlük: %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/burst_screenshots_dialog.cpp" line="54"/>
        <source>Size: %1</source>
        <translation>Boyut: %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/burst_screenshots_dialog.cpp" line="77"/>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
</context>
<context>
    <name>dmr::MainWindow</name>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="1013"/>
        <source>Load successfully</source>
        <translation>Yüklendi</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="1013"/>
        <source>Load failed</source>
        <translation>Yüklenemedi</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="1852"/>
        <source>Cannot play the disc</source>
        <translation>Disk oynatılamıyor</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="1869"/>
        <source>Parse failed</source>
        <translation>Ayrıştırma başarısız</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="1877"/>
        <source>Open folder</source>
        <translation>Klasör aç</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2284"/>
        <source>Speed: %1x</source>
        <translation>Hız: %1x</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2323"/>
        <source>Stereo</source>
        <translation>Çift kanal</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2328"/>
        <source>Left channel</source>
        <translation>Sol kanal</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2333"/>
        <source>Right channel</source>
        <translation>Sağ kanal</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2438"/>
        <source>Track: %1</source>
        <translation>Parça: %1</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2480"/>
        <source>Unable to adjust the subtitle</source>
        <translation>Altyazı ayarlanamıyor</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2485"/>
        <source>Subtitle %1: %2s</source>
        <translation>Alt yazı %1: %2s</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2486"/>
        <source>delayed</source>
        <translation>gecikme</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2486"/>
        <source>advanced</source>
        <translation>gelişmiş</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2644"/>
        <source>View</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2653"/>
        <source>Film screenshot</source>
        <translation>Film ekran görüntüsü</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2654"/>
        <source>Saved to</source>
        <translation>Şuraya kaydedildi</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2675"/>
        <source>The screenshot is saved</source>
        <translation>Ekran görüntüsü kaydedildi</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2679"/>
        <source>Failed to save the screenshot</source>
        <translation>Ekran görüntüsü kaydedilemedi</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2763"/>
        <source>Taking the screenshots, please wait...</source>
        <translation>Ekran görüntüleri çekiliyor, lütfen bekleyin...</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2848"/>
        <source>Cancel</source>
        <translation type="unfinished">İptal</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2849"/>
        <source>Restart</source>
        <translation>Yeniden başlat</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3054"/>
        <source>Reading DVD files...</source>
        <translation>DVD dosyaları okunuyor...</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4966"/>
        <source>Invalid file: %1</source>
        <translation>Dosya geçersiz: %1</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4997"/>
        <source>Miracast disconnected</source>
        <translation>Miracast&apos;ın bağlantısı kesildi</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3275"/>
        <source>No matching online subtitles</source>
        <translation>Eşleşen çevrimiçi altyazı yok</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="1913"/>
        <source>All (*)</source>
        <translation>Tümü (*)</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3291"/>
        <source>4K video may be stuck</source>
        <translation>4K video sıkışmış olabilir</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3292"/>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3324"/>
        <source>Order play</source>
        <translation>Oynatma sırası</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3327"/>
        <source>Shuffle play</source>
        <translation>Karışık oynat</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3330"/>
        <source>Single play</source>
        <translation>Tek oynat</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3333"/>
        <source>Single loop</source>
        <translation>Tek döngü</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3336"/>
        <source>List loop</source>
        <translation>Liste döngüsü</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3480"/>
        <source>Buffering...</source>
        <translation>Arabelleğe alınıyor...</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3503"/>
        <source>Mute</source>
        <translation>Sesi kapat</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3505"/>
        <source>Volume: %1%</source>
        <translation>Ses: %1%</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3548"/>
        <source>Cannot open file or stream</source>
        <translation>Dosya veya akış açılamıyor</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4955"/>
        <source>The action is not supported in this video</source>
        <translation>Eylem bu videoda desteklenmiyor</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4990"/>
        <source>Connection failed</source>
        <translation>Bağlantı başarısız</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3616"/>
        <source>Invalid file</source>
        <translation>Geçersiz dosya</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2531"/>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <comment>All (*)</comment>
        <translation>Alt yazı (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3623"/>
        <source>Please insert a CD/DVD</source>
        <translation>Lütfen bir CD/DVD yerleştirin</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3628"/>
        <source>No video file found</source>
        <translation>Video dosyası bulunamadı</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4279"/>
        <source>Please load the video first</source>
        <translation>Lütfen önce videoyu yükleyin</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4402"/>
        <source>Please exit smart dock</source>
        <translation>Lütfen akıllı rıhtımdan çıkın</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4715"/>
        <source>The CD/DVD has been ejected</source>
        <translation>CD/DVD çıkarıldı</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfo</name>
    <message>
        <source>%1G</source>
        <translation type="vanished">%1G</translation>
    </message>
    <message>
        <source>%1M</source>
        <translation type="vanished">%1M</translation>
    </message>
    <message>
        <source>%1K</source>
        <translation type="vanished">%1K</translation>
    </message>
    <message>
        <source>%1</source>
        <translation type="vanished">%1</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfoDialog</name>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="243"/>
        <source>Film info</source>
        <translation>Film bilgileri</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="295"/>
        <source>Type</source>
        <translation>Tür</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="296"/>
        <source>Size</source>
        <translation>Boyut</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="297"/>
        <source>Duration</source>
        <translation>Süre</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="302"/>
        <source>Path</source>
        <translation>Yol</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="307"/>
        <source>Codec info</source>
        <translation>Çözücü bilgisi</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="328"/>
        <source>Video CodecID</source>
        <translation>Video ÇözücüID</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="329"/>
        <source>Video CodeRate</source>
        <translation>Video KodHızı</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="275"/>
        <source>%1 kbps</source>
        <translation>%1 kbps</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="276"/>
        <source>%1 bps</source>
        <translation>%1 bps</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="330"/>
        <source>FPS</source>
        <translation>FPS</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="278"/>
        <source>%1 fps</source>
        <translation>%1 fps</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="331"/>
        <source>Proportion</source>
        <translation>Oran</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="279"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="332"/>
        <source>Resolution</source>
        <translation>Çözünürlük</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="337"/>
        <source>Audio info</source>
        <translation>Sesli bilgi</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="358"/>
        <source>Audio CodecID</source>
        <translation>Ses ÇözücüID</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="359"/>
        <source>Audio CodeRate</source>
        <translation>Ses KodHızı</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="360"/>
        <source>Audio digit</source>
        <translation>Sesli rakam</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="291"/>
        <source>%1 bits</source>
        <translation>%1 bits</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="361"/>
        <source>Channels</source>
        <translation>Kanallar</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="292"/>
        <source>%1 channels</source>
        <translation>%1 kanal</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="362"/>
        <source>Sampling</source>
        <translation>Örnekleme</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="293"/>
        <source>%1hz</source>
        <translation>%1hz</translation>
    </message>
</context>
<context>
    <name>dmr::MpvProxy</name>
    <message>
        <location filename="../src/backends/mpv/mpv_proxy.cpp" line="1990"/>
        <source>Internal</source>
        <translation>Dahili</translation>
    </message>
</context>
<context>
    <name>dmr::Platform_MainWindow</name>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="1037"/>
        <source>Load successfully</source>
        <translation>Yüklendi</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="1037"/>
        <source>Load failed</source>
        <translation>Yüklenemedi</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="1915"/>
        <source>Cannot play the disc</source>
        <translation>Disk oynatılamıyor</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="1932"/>
        <source>Parse failed</source>
        <translation>Ayrıştırma başarısız</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="1940"/>
        <source>Open folder</source>
        <translation>Klasör aç</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="1968"/>
        <source>All (*)</source>
        <translation>Tümü (*)</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2300"/>
        <source>Speed: %1x</source>
        <translation>Hız: %1x</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2339"/>
        <source>Stereo</source>
        <translation>Çift kanal</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2344"/>
        <source>Left channel</source>
        <translation>Sol kanal</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2349"/>
        <source>Right channel</source>
        <translation>Sağ kanal</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2454"/>
        <source>Track: %1</source>
        <translation>Parça: %1</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2496"/>
        <source>Unable to adjust the subtitle</source>
        <translation>Altyazı ayarlanamıyor</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2501"/>
        <source>Subtitle %1: %2s</source>
        <translation>Alt yazı %1: %2s</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2502"/>
        <source>delayed</source>
        <translation>gecikme</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2502"/>
        <source>advanced</source>
        <translation>gelişmiş</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2547"/>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <comment>All (*)</comment>
        <translation>Alt yazı (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2670"/>
        <source>View</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2679"/>
        <source>Film screenshot</source>
        <translation>Film ekran görüntüsü</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2680"/>
        <source>Saved to</source>
        <translation>Şuraya kaydedildi</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2701"/>
        <source>The screenshot is saved</source>
        <translation>Ekran görüntüsü kaydedildi</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2705"/>
        <source>Failed to save the screenshot</source>
        <translation>Ekran görüntüsü kaydedilemedi</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2789"/>
        <source>Taking the screenshots, please wait...</source>
        <translation>Ekran görüntüleri çekiliyor, lütfen bekleyin...</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2873"/>
        <source>Cancel</source>
        <translation type="unfinished">İptal</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2874"/>
        <source>Restart</source>
        <translation>Yeniden başlat</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3064"/>
        <source>Reading DVD files...</source>
        <translation>DVD dosyaları okunuyor...</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3268"/>
        <source>No matching online subtitles</source>
        <translation>Eşleşen çevrimiçi altyazı yok</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3284"/>
        <source>4K video may be stuck</source>
        <translation>4K video sıkışmış olabilir</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3285"/>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3326"/>
        <source>Order play</source>
        <translation>Oynatma sırası</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3329"/>
        <source>Shuffle play</source>
        <translation>Karışık oynat</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3332"/>
        <source>Single play</source>
        <translation>Tek oynat</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3335"/>
        <source>Single loop</source>
        <translation>Tek döngü</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3338"/>
        <source>List loop</source>
        <translation>Liste döngüsü</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3476"/>
        <source>Buffering...</source>
        <translation>Arabelleğe alınıyor...</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3499"/>
        <source>Mute</source>
        <translation>Sesi kapat</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3501"/>
        <source>Volume: %1%</source>
        <translation>Ses: %1%</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3570"/>
        <source>Cannot open file or stream</source>
        <translation>Dosya veya akış açılamıyor</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3587"/>
        <source>Invalid file</source>
        <translation>Geçersiz dosya</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3594"/>
        <source>Please insert a CD/DVD</source>
        <translation>Lütfen bir CD/DVD yerleştirin</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3600"/>
        <source>No video file found</source>
        <translation>Video dosyası bulunamadı</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4283"/>
        <source>Please load the video first</source>
        <translation>Lütfen önce videoyu yükleyin</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4403"/>
        <source>Please exit smart dock</source>
        <translation>Lütfen akıllı rıhtımdan çıkın</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4655"/>
        <source>The CD/DVD has been ejected</source>
        <translation>CD/DVD çıkarıldı</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4901"/>
        <source>The action is not supported in this video</source>
        <translation>Eylem bu videoda desteklenmiyor</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4912"/>
        <source>Invalid file: %1</source>
        <translation>Dosya geçersiz: %1</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4936"/>
        <source>Connection failed</source>
        <translation>Bağlantı başarısız</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4943"/>
        <source>Miracast disconnected</source>
        <translation>Miracast&apos;ın bağlantısı kesildi</translation>
    </message>
</context>
<context>
    <name>dmr::Platform_PlayItemWidget</name>
    <message>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="163"/>
        <source>The file does not exist</source>
        <translation>Dosya yok</translation>
    </message>
</context>
<context>
    <name>dmr::Platform_PlaylistWidget</name>
    <message>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="679"/>
        <source>Playlist</source>
        <translation>Oynatma listesi</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="705"/>
        <source>Empty</source>
        <translation>Boşalt</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="910"/>
        <source>%1 videos</source>
        <translation>%1 video</translation>
    </message>
</context>
<context>
    <name>dmr::Platform_ToolboxProxy</name>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1189"/>
        <source>Play/Pause</source>
        <translation>Oynat/Duraklat</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1189"/>
        <source>Previous</source>
        <translation>Önceki</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1189"/>
        <source>Next</source>
        <translation>Sonraki</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1190"/>
        <source>Fullscreen</source>
        <translation>Tam ekran</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1190"/>
        <source>Playlist</source>
        <translation>Oynatma listesi</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1190"/>
        <source>Miracast</source>
        <translation>Miracast</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="2132"/>
        <source>Exit fullscreen</source>
        <translation>Tam ekrandan çık</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="2217"/>
        <source>Pause</source>
        <translation>Duraklat</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="2277"/>
        <source>Play</source>
        <translation>Oynat</translation>
    </message>
</context>
<context>
    <name>dmr::PlayItemWidget</name>
    <message>
        <location filename="../src/widgets/playlist_widget.cpp" line="163"/>
        <source>The file does not exist</source>
        <translation>Dosya yok</translation>
    </message>
</context>
<context>
    <name>dmr::PlaylistWidget</name>
    <message>
        <location filename="../src/widgets/playlist_widget.cpp" line="679"/>
        <source>Playlist</source>
        <translation>Oynatma listesi</translation>
    </message>
    <message>
        <location filename="../src/widgets/playlist_widget.cpp" line="705"/>
        <source>Empty</source>
        <translation>Boşalt</translation>
    </message>
    <message>
        <location filename="../src/widgets/playlist_widget.cpp" line="910"/>
        <source>%1 videos</source>
        <translation>%1 video</translation>
    </message>
</context>
<context>
    <name>dmr::Settings</name>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="119"/>
        <source>Order play</source>
        <translation>Oynatma sırası</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="120"/>
        <source>Shuffle play</source>
        <translation>Karışık oynat</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="121"/>
        <source>Single play</source>
        <translation>Tek oynat</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="122"/>
        <source>Single loop</source>
        <translation>Tek döngü</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="123"/>
        <source>List loop</source>
        <translation>Liste döngüsü</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="129"/>
        <source>Auto</source>
        <translation>Otomatik</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="130"/>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="131"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="294"/>
        <source>%1/Movie%2(%3).jpg</source>
        <translation>%1/Sinema%2(%3).jpg</translation>
    </message>
</context>
<context>
    <name>dmr::ToolboxProxy</name>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1313"/>
        <source>Play/Pause</source>
        <translation>Oynat/Duraklat</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1313"/>
        <source>Previous</source>
        <translation>Önceki</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1313"/>
        <source>Next</source>
        <translation>Sonraki</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1314"/>
        <source>Fullscreen</source>
        <translation>Tam ekran</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1314"/>
        <source>Playlist</source>
        <translation>Oynatma listesi</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1314"/>
        <source>Miracast</source>
        <translation>Miracast</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2306"/>
        <source>Exit fullscreen</source>
        <translation>Tam ekrandan çık</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2402"/>
        <source>Pause</source>
        <translation>Duraklat</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2467"/>
        <source>Play</source>
        <translation>Oynat</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2842"/>
        <source>Volume</source>
        <translation type="unfinished">Ses</translation>
    </message>
</context>
<context>
    <name>dmr::VolumeButton</name>
    <message>
        <location filename="../src/widgets/toolbutton.cpp" line="19"/>
        <source>Volume</source>
        <translation>Ses</translation>
    </message>
</context>
</TS>
